/**
 * Run karma.
 * @memberof module:apeman-dev-commons-testing/lib
 * @function runKarma
 * @param {string} command - Karma command.
 * @param {string} conf - Karma conf file path.
 * @param {options} [options] - Optional setting.
 * @param {function} [callback] - Callback when done.
 */

"use strict";

var argx = require('argx'),
    async = require('async'),
    hasbin = require('hasbin'),
    h = require('./_helper'),
    execcli = require('execcli');


/** @lends runKarma */
function runKarma(command, conf, options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    command = args.shift('string');
    conf = args.shift('string');

    hasbin('karma', function (hasKarma) {
        if (!hasKarma) {
            callback(new Error('karma not found. try `npm install karma -g`.'));
            return;
        }

        h.start();

        async.series([
            function (callback) {
                execcli('karma', [command, conf, options || {}], callback);
            }
        ], function (err) {
            h.end(err);
            callback(err);
        });
    });
}

module.exports = runKarma;